==> DynamicJasper-2.0.8-sources.jar: ar/com/fdvs/dj/domain/ColumnProperty.java <==
/*
 * Dynamic Jasper: A library for creating reports dynamically by specifying
 * columns, groups, styles, etc. at runtime. It also saves a lot of development
 * time in many cases! (http://sourceforge.net/projects/dynamicjasper)
 *
 * Copyright (C) 2008  FDV Solutions (http://www.fdvsolutions.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 *
 * License as published by the Free Software Foundation; either
 *
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *
 */

package ar.com.fdvs.dj.domain;

public class ColumnProperty {

	private String property;
	private String valueClassName;

    public ColumnProperty(String property, String valueClass) {
    	this.setProperty(property);
    	this.setValueClassName(valueClass);
    }

	public ColumnProperty() {
		super();
	}

    public String getProperty() {
		return property;
	}

	public void setProperty(String property) {
		this.property = property;
	}

	public String getValueClassName() {
		return valueClassName;
	}

    public void setValueClassName(String valueClass) {
		this.valueClassName = valueClass;
	}

}

==> DynamicJasper-3.0.5-sources.jar: ar/com/fdvs/dj/domain/ColumnProperty.java <==
/*
 * DynamicJasper: A library for creating reports dynamically by specifying
 * columns, groups, styles, etc. at runtime. It also saves a lot of development
 * time in many cases! (http://sourceforge.net/projects/dynamicjasper)
 *
 * Copyright (C) 2008  FDV Solutions (http://www.fdvsolutions.com)
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 *
 * License as published by the Free Software Foundation; either
 *
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 *
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *
 */

package ar.com.fdvs.dj.domain;

import ar.com.fdvs.dj.util.PropertiesMap;

public class ColumnProperty {

	private String property;
	private String valueClassName;
	private PropertiesMap fieldProperties = new PropertiesMap();

    public ColumnProperty(String property, String valueClass) {
    	this.setProperty(property);
    	this.setValueClassName(valueClass);
    }

	public ColumnProperty() {
		super();
	}

    public String getProperty() {
		return property;
	}

	public void setProperty(String property) {
		this.property = property;
	}

	public String getValueClassName() {
		return valueClassName;
	}

    public void setValueClassName(String valueClass) {
		this.valueClassName = valueClass;
	}

	public PropertiesMap getFieldProperties() {
		return fieldProperties;
	}

	public void setFieldProperties(PropertiesMap fieldProperties) {
		this.fieldProperties = fieldProperties;
	}

	public Object addFieldProperty(String key, String value) {
		return fieldProperties.put(key, value);
	}

}
